@@ -14,7 +14,7 @@ has 'backend';
 has remove_after => 864000;
 has tasks => sub { {} };
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 sub add_task {
   my ($self, $name, $cb) = @_;
@@ -87,7 +87,8 @@ Minion - Job queue
   use Minion;
 
   # Connect to backend
-  my $minion = Minion->new(File  => '/Users/sri/minion.db');
+  my $minion = Minion->new(File => '/Users/sri/minion.db');
+  my $minion = Minion->new(Pg   => 'postgresql://postgres@/test');
 
   # Add tasks
   $minion->add_task(something_slow => sub {
@@ -164,7 +165,7 @@ Application for job queue, defaults to a L<Mojo::HelloWorld> object.
   my $backend = $minion->backend;
   $minion     = $minion->backend(Minion::Backend::File->new);
 
-Backend, usually a L<Minion::Backend::File> object.
+Backend, usually a L<Minion::Backend::File> or L<Minion::Backend::Pg> object.
 
 =head2 remove_after
 
@@ -269,6 +270,16 @@ Build L<Minion::Worker> object.
 
 Sebastian Riedel, C<sri@cpan.org>.
 
+=head1 CREDITS
+
+In alphabetical order:
+
+=over 2
+
+Brian Medley
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2014, Sebastian Riedel.
